@@ -2,15 +2,15 @@ package WWW::Wookie::Widget::Instances;   # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-# $Id: Instances.pm 357 2010-11-07 10:53:18Z roland $
-# $Revision: 357 $
+# $Id: Instances.pm 362 2010-11-23 23:06:49Z roland $
+# $Revision: 362 $
 # $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/barclay/trunk/lib/WWW/Wookie/Widget/Instances.pm $
-# $Date: 2010-11-07 11:53:18 +0100 (Sun, 07 Nov 2010) $
+# $Date: 2010-11-24 00:06:49 +0100 (Wed, 24 Nov 2010) $
 
 use utf8;
 use 5.006000;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moose qw/around has/;
 use MooseX::AttributeHelpers;
@@ -26,7 +26,7 @@ has _instances => (
 
 sub put {
     my ( $self, $instance ) = @_;
-    $self->_instances->{ $instance->getIdentifier() } = $instance;
+    $self->_instances->{ $instance->getIdentifier } = $instance;
     return;
 }
 
@@ -47,7 +47,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Roland van Ipenburg Readonly
+=for stopwords Roland van Ipenburg
 
 =head1 NAME
 
@@ -56,7 +56,7 @@ available to a host
 
 =head1 VERSION
 
-This document describes WWW::Wookie::Widget::Instances version 0.0.2
+This document describes WWW::Wookie::Widget::Instances version 0.03
 
 =head1 SYNOPSIS
 
@@ -92,7 +92,6 @@ Get all Widget instances. Returns an array of widget instances.
 
 L<Moose|Moose>
 L<MooseX::AttributeHelpers|MooseX::AttributeHelpers>
-L<Readonly|Readonly>
 L<WWW::Wookie::Widget::Instance|WWW::Wookie::Widget::Instance>
 
 =head1 INCOMPATIBILITIES
